antares.apps.initialsettings package — Antares 0.0.2 documentation

# antares.apps.initialsettings package

## Subpackages

- antares.apps.initialsettings.console package
  - Submodules
  - antares.apps.initialsettings.console.initial_settings_console module
  - antares.apps.initialsettings.console.isic_console module
  - Module contents
- antares.apps.initialsettings.manager package
  - Submodules
  - antares.apps.initialsettings.manager.initial_settings_loader module
  - antares.apps.initialsettings.manager.isic_loader module
  - Module contents
- antares.apps.initialsettings.migrations package
  - Module contents
- antares.apps.initialsettings.tests package
  - Module contents

## Submodules

## antares.apps.initialsettings.constants module

## Module contents